# This package used to be called "google-perftools", but it was renamed on 2012-02-03.

%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

Name:		gperftools
Version:	2.6.2
Release:	1%{?dist}
License:	BSD
Group:		Development/Tools
Summary:	Very fast malloc and performance analysis tools
URL:		http://code.google.com/p/gperftools/
Source0:	https://googledrive.com/host/0B6NtGsLhIcf7MWxMMF9JdTN3UVk/%{name}-%{version}.tar.gz


Requires:	gperftools-devel = %{version}-%{release}
Requires:	pprof = %{version}-%{release}

%description
Perf Tools is a collection of performance analysis tools, including a 
high-performance multi-threaded malloc() implementation that works
particularly well with threads and STL, a thread-friendly heap-checker,
a heap profiler, and a cpu-profiler.

This is a metapackage which pulls in all of the gperftools (and pprof)
binaries, libraries, and development headers, so that you can use them.

%package devel
Summary:	Development libraries and headers for gperftools
Group:		Development/Libraries
Requires:	%{name}-libs%{?_isa} = %{version}-%{release}
Provides:	google-perftools-devel = %{version}-%{release}
Obsoletes:	google-perftools-devel < 2.0

%description devel
Libraries and headers for developing applications that use gperftools.

%package libs
Summary:	Libraries provided by gperftools
Provides:	google-perftools-libs = %{version}-%{release}
Obsoletes:	google-perftools-libs < 2.0

%description libs
Libraries provided by gperftools, including libtcmalloc and libprofiler.

%package -n pprof
Summary:	CPU and Heap Profiler tool
Requires:	graphviz
BuildArch:	noarch
Provides:	google-perftools = %{version}-%{release}
Obsoletes:	google-perftools < 2.0

%description -n pprof 
Pprof is a heap and CPU profiler tool, part of the gperftools suite.

%prep
%setup -q -n gperftools-%{name}-%{version}

# Fix end-of-line encoding
sed -i 's/\r//' README_windows.txt

# No need to have exec permissions on source code
chmod -x src/*.h src/*.cc

%build
autoreconf -i
CFLAGS=`echo $RPM_OPT_FLAGS -fno-strict-aliasing -Wno-unused-local-typedefs -DTCMALLOC_LARGE_PAGES | sed -e 's|-fexceptions||g'`
CXXFLAGS=`echo $RPM_OPT_FLAGS -fno-strict-aliasing -Wno-unused-local-typedefs -DTCMALLOC_LARGE_PAGES | sed -e 's|-fexceptions||g'`
%configure --disable-static --disable-libunwind

# Bad rpath!
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
# Can't build with smp_mflags
make 

%install
make DESTDIR=%{buildroot} docdir=%{_pkgdocdir}/ install
find %{buildroot} -type f -name "*.la" -exec rm -f {} ';'

# Delete useless files
rm -rf %{buildroot}%{_pkgdocdir}/INSTALL

%check
# http://code.google.com/p/google-perftools/issues/detail?id=153
%ifnarch ppc
# Their test suite is almost always broken.
# LD_LIBRARY_PATH=./.libs make check
%endif

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files

%files -n pprof
%{_bindir}/pprof
%{_mandir}/man1/*

%files devel
%{_pkgdocdir}/
%{_includedir}/google/
%{_includedir}/gperftools/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files libs
%{_libdir}/*.so.*

%changelog
* Thu Nov 30 2017 Ernani Azevedo <azevedo@voipdomain.io> - 2.6.2-1
- gperftools 2.6.2 is out!
-
- Most notable change is recently added support for C++17 over-aligned allocation
- operators contributed by Andrey Semashev. I've extended his implementation to
- have roughly same performance as malloc/new. This release also has native
- support for C11 aligned_alloc.
-
- Rest is mostly bug fixes:
-
- * Jianbo Yang has contributed a fix for potentially severe data raceintroduced
-   by malloc fast-path work in gperftools 2.6. This race could cause occasional
-   violation of total thread cache size constraint. See issue #929 for more
-   details.
- * Correct behavior in out-of-memory condition in fast-path cases was restored.
-   This was another bug introduced by fast-path optimization in gperftools 2.6
-   which caused operator new to silently return NULL instead of doing correct
-   C++ OOM handling (calling new_handler and throwing bad_alloc).
- * Khem Raj has contributed couple build fixes for newer glibcs (ucontext_t vs
-   struct ucontext and loff_t definition)
- * Piotr Sikora has contributed build fix for OSX (not building unwind
-   benchmark). This was issue #910 (thanks to Yuriy Solovyov for reporting it).
- * Dorin Lazăr has contributed fix for compiler warning
- * issue #912 (occasional deadlocking calling getenv too early on windows) was
-   fixed. Thanks to github user shangcangriluo for reporting it.
- * Couple earlier lsan-related commits still causing occasional issues linking
-   on OSX has been reverted. See issue #901.
- * Volodimir Krylov has contributed GetProgramInvocationName for FreeBSD
- * changsu lee has contributed couple minor correctness fixes (missing va_end()
-   and missing free() call in rarely executed Symbolize path)
- * Andrew C. Morrow has contributed some more page heap stats. See issue #935.
- * some cases of built-time warnings from various gcc/clang versions about
-   throw() declarations have been fixes.

* Thu Oct 12 2017 Miroslav Rezanina <mrezanin@redhat.com> - 2.4-8.el7
- Rebase to 2.6.1 [bz#1431240]
- Removed libunwind usage [bz#1467203]
- Resolves: bz#1431240 
  (gperftools fails to build on s390x, lacks s390x support)
- Resolves: bz#1467203
  (Please, remove libunwind from the gperftools-libs (and 389-ds-base) requirements)

* Wed Jun 22 2016 Miroslav Rezanina <mrezanin@redhat.com> - 2.4-8.el7
- gp-Use-initial-exec-tls-for-libunwind-s-recursion-flag.patch [bz#1339710]
- Resolves: bz#1339710
  (initalization of 'recursive' tls variable in libunwind stack capturer occasionally triggers deadlock in ceph)

* Wed Aug 26 2015 Miroslav Rezanina <mrezanin@redhat.com> 2.4-7
- Rebuild to fix NVR [bz#1269032]
- Resolves: bz#1269032
  (gperftools NVR lower than EPEL version)

* Wed Aug 26 2015 Miroslav Rezanina <mrezanin@redhat.com> 2.4-2
- gperf-allow-customizing-trace-filename.patch [bz#1232702]
- Resolves: bz#1232702
  (gperftools: tcmalloc debug version uses hard-coded path /tmp/google.alloc) 

* Tue Jun 02 2015 Miroslav Rezanina <mrezanin@redhat.com> 2.4-1
- Import to RHEL
